#!/usr/bin/python
#-----------------------------------------------------------------------
# File    : runexp.py
# Contents: front end for surrogate generation experiments
# Author  : Christian Borgelt
# History : 2009.08.22 file created
#           2009.08.24 bug concerning exit code fixed
#           2009.09.01 grids for parameter ranges to test defined
#           2009.09.02 some duplicate parameter settings removed
#           2009.09.04 adapted to generalized parameter grids
#           2009.09.05 output of filename added for testing
#           2014.05.27 modules placed in sibling directories
#-----------------------------------------------------------------------
from sys        import argv, path
from os.path    import join
UTILDIR = join('..', 'util')
if UTILDIR not in path: path.insert(0, UTILDIR)
from id2par     import run, get_args
from surrogates import run_exps, get_fname

#-----------------------------------------------------------------------

runs  = [1000]
grids = [ # table, set 1 to set 5, FP/FN
          # 60 parameter combinations (5x2 values x 6 methods)
          [ ( { 'rate': 37.75, 'delta': 0,     'shape': 1 },   # set 1
              { 'rate': 0,     'delta': 0,     'shape': 1 },   # set 2
              { 'rate': 37.75, 'delta': 0.235, 'shape': 1 },   # set 3
              { 'rate': 0,     'delta': 0.5,   'shape': 1 },   # set 4
              { 'rate': 0,     'delta': 0.5,   'shape': 3 } ), # set 5
            ('inject', [0,2]),  # no coins. / coins. with 2 Hz
            ('method', [0,1,2,3,4,5]),
            ('runs',   runs) ],
          # figure: FN over injection rate
          # 24 parameter combinations (4 values x 6 methods)
          [ ('rate',   [  0]),  # non-stationary within trials
            ('delta',  [0.5]),  # non-stationary across trials
            ('shape',  [  3]),  # Gamma process with shape 3
            ('inject', [1,1.5,2.5,3]),
            # inject = 2 is contained in set 5 for the table
            ('method', [0,1,2,3,4,5]),
            ('runs',   runs) ],
          # figure: FP over shape parameter
          # 48 parameter combinations (8 values x 6 methods)
          [ ('rate',   [  0]),  # non-stationary within trials
            ('delta',  [0.5]),  # non-stationary across trials
            ('shape',  [0.4,0.6,0.8,2,4,5,8,10]),
            # shape = 1 is contained in set 4 for the table
            # shape = 3 is contained in set 5 for the table
            ('inject', [  0]),  # no injected coincidences
            ('method', [0,1,2,3,4,5]),
            ('runs',   runs) ],
          # figure: FN/FP over delta (non-stationarity across trials)
          # 72 parameter combinations (6x2 values x 6 methods)
          [ ('rate',   [  0]),  # non-stationary within trials
            ('delta',  [0,0.2,0.4,0.6,0.8,1]),
            ('shape',  [  3]),  # Gamma process with shape 3
            ('inject', [0,2]),  # no coins. / coins. with 2Hz
            ('method', [0,1,2,3,4,5]),
            ('runs',   runs) ],
          # total: 204 parameter combinations
          #      =  34 parameter settings x 6 methods
        ]

if len(argv) <= 1 or int(argv[1]) <= 0:
    print get_args(grids); exit()

print argv[0], argv[1]
if len(argv) < 3: run(run_exps,  grids, int(argv[1])-1)
else:       print run(get_fname, grids, int(argv[1])-1)

# usage: runexp.py [id]
# If no id or an id value <= 0 is given, the maximum id is printed.
# The id range is then [1..n] where n is the printed maximum id.
# Otherwise a surrogate data experiment for the id-th parameter
# combination as defined by the above parameter grids is executed.
